@@ -4,6 +4,8 @@
 #'
 #' Due to package size constraints the data are stored externally (and a working internet connection is required to use the package). Downloaded size is 118.6 KB.
 #'
+#' @param method Method argument for `download.file()`. The default (i.e. "curl") should be appropriate in most situations.
+#'
 #' @format \code{sf} data frame with 480 rows of 5 variables + geometry
 #'
 #' \describe{
@@ -19,7 +21,7 @@
 #'
 #' @export
 
-plochy <- function() {
+plochy <- function(method = "curl") {
 
   remote_path <- 'http://rczechia.jla-data.net/'
 
@@ -41,7 +43,7 @@ plochy <- function() {
     } else {
 
       message('RCzechia: downloading remote dataset.')
-      download.file(url = remote_file, destfile = local_file, quiet = T)
+      download.file(url = remote_file, destfile = local_file, method = method, quiet = T)
     }
   }
 
